'use client'
import React, {useState, useEffect} from 'react'
import {Button} from "@/components/ui/button";
import {
 Menubar,
 MenubarCheckboxItem,
 MenubarContent,
 MenubarItem,
 MenubarMenu,
 MenubarRadioGroup,
 MenubarRadioItem,
 MenubarSeparator,
 MenubarShortcut,
 MenubarSub,
 MenubarSubContent,
 MenubarSubTrigger,
 MenubarTrigger,
} from "@/components/ui/menubar"
import store from "store2";
import {IResMeData} from "@/types/response";
import {
 CalendarDays,
 CalendarFold,
 CalendarHeart,
 CalendarPlus,
 CalendarRange,
 Server,
 Loader2,
 Unplug,
 User,
 UserCog
} from "lucide-react";
import { toNamespacedPath } from 'path';

import { useToast } from "@/components/ui/use-toast"

function HeaderAccountContainer() {
  const { toast } = useToast()
  const [userData, setUserData] = useState(null)
  const [isLoggedIn, setLoggedIn] = useState(true)
  store.set('jwt', 'eyJhbGciOiJIUzUxMiJ9.eyJzdWIiOiI5Yzg0MzQyYS1lNWQwLTQyYTAtYmE0Yy03OTBhN2E5ODQ2ZDMiLCJpYXQiOjE3MTM1MTcyMjUsImlzcyI6IkJyaWVmIDAzIC0gTWF0aGlzIEhFUlJJT1QiLCJhdWQiOiJ1c2VyIiwiZXhwIjoxNzEzNjAzNjI1fQ.uDXaO4DqcFab5TF0tnDm5FQHhUypXbLH8OQ8U45UUaQ_0zkWZxTO06k4GYCZvGS6qXJ9KW1M8K_BnpgaKyvcGg')
  const token = store.get('jwt')

  useEffect(() => {
    fetch('http://localhost:3333/auth/me', {
     method: 'GET',
     headers: {
      'Authorization': `Bearer ${token}`,
     }
    })
      .then((res) => {
        console.log(res.status)
       if (res.status !== 200) {
        toast({
         title: "User not found",
         variant: "destructive"
        })
        setLoggedIn(false)
        return null
       }
       return res.json()
      })
      .then((data: IResMeData | never) => {
        // @ts-ignore
       setUserData(data)
       if (!userData) return;
        // @ts-ignore
       if (userData?.displayName) setLoggedIn(true)
      })
  }, [])

  if (!isLoggedIn && !userData) {
   return (
     <>
      <div className="flex items-center justify-center gap-1 m-1">
       <Button className={"italic hover:bg-accent-foreground dark:hover:bg-accent"}>Connexion</Button>
       <Button
         className={"bg-accent dark:text-primary-foreground text-accent-foreground dark:hover:bg-primary hover:bg-accent-foreground hover:text-accent italic"}>Inscription</Button>
      </div>
     </>
   )
  }

  if (isLoggedIn && userData) {
   return (
     <>
      <div className="flex items-center justify-center gap-1 m-1">
       <Menubar>
        <MenubarMenu>
         <MenubarTrigger className={'gap-1'}>
          <CalendarRange />
          Êvenements
         </MenubarTrigger>
         <MenubarContent>
          <MenubarItem className={'gap-1'} onClick={()=>{
           window.location.href = "/events/new"
          }}>
           <CalendarPlus />
           Créer un êvenement
          </MenubarItem>
          <MenubarItem className={'gap-1'} onClick={()=>{
           window.location.href = "/events/subscribed"
          }}>
           <CalendarHeart />
           Mes inscriptions
          </MenubarItem>
          <MenubarItem className={'gap-1'} onClick={()=>{
           window.location.href = "/events/owned"
          }}>
           <CalendarFold />
           Mes êvenements
          </MenubarItem>
          <MenubarSeparator />
          <MenubarItem className={'gap-1'} onClick={()=>{
           window.location.href = "/events"
          }}>
           <CalendarDays />
           Explorer...
          </MenubarItem>
         </MenubarContent>
        </MenubarMenu>
        <MenubarMenu>
         <MenubarTrigger className={'gap-1'}>
          <User />
          {
           //@ts-ignore
           userData.displayName
          }
         </MenubarTrigger>
         <MenubarContent>
          <MenubarItem className={'gap-1'} onClick={()=>{
           window.location.href = "/account"
          }}>
           <UserCog />
           Mon profil
          </MenubarItem>
          <MenubarItem className={`gap-1 ${
            //@ts-ignore
            userData.isAdmin ? "text-primary" : "hidden"}`
          }  onClick={()=>{
           window.location.href = "/admin"
          }}>
           <Server />
           Administration
          </MenubarItem>

          <MenubarItem onClick={()=>{
           store.remove('jwt')
           setLoggedIn(false)
           setTimeout(()=>{window.location.reload()}, 1_500)
          }} className={'gap-1'}>
           <Unplug />
           Déconnexion
          </MenubarItem>
         </MenubarContent>
        </MenubarMenu>
       </Menubar>
      </div>
     </>
   )
  }

  return (
    <>
     <Button disabled>
      <Loader2 className="mr-2 h-4 w-4 animate-spin" />
       Chargement...
     </Button>
    </>
  )

}
export default HeaderAccountContainer;
