'use client'
import React from 'react'
import { zodResolver } from "@hookform/resolvers/zod"
import { useForm } from "react-hook-form"
import { z } from "zod"
import { Button } from "@/components/ui/button"
import {
 Form,
 FormControl,
 FormDescription,
 FormField,
 FormItem,
 FormLabel,
 FormMessage,
} from "@/components/ui/form"

import { Input } from "@/components/ui/input"
import {Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle} from "@/components/ui/card";

const formSchema = z.object({
 title: z.string().min(4).max(32),
 subTitle: z.string().min(4).max(64),
 base64Banner: z.any()
   .refine((file: File)=> file?.size < 1_024_000, "Le fichier fait plus de 1Mo"),
 desc: z.string().max(128),
 date: z.date().min(new Date()),
 were: z.string(),
 maxMembers: z.number().int()

})

export const NewEventForm = () => {
 const form = useForm<z.infer<typeof formSchema>>({
  resolver: zodResolver(formSchema),
  defaultValues: {
   title: "Mon êvenement",
   subTitle: "Lorem ipsum dolor..."
  },
 })
 function onSubmit(values: z.infer<typeof formSchema>) {
  console.log("submit")
  // Do something with the form values.
  // ✅ This will be type-safe and validated.
  console.log(values)
 }
 return (
   <>
    <Card className={'md:w-3/4'}>
     <CardHeader>
      <CardTitle>Créer un nouvel êvènement</CardTitle>
      <CardDescription>Veuillez saissir tout les champs.</CardDescription>
     </CardHeader>
     <CardContent>
      <Form {...form}>
       <form onSubmit={(event)=>{
        event.preventDefault()
        console.log('p')
        form.handleSubmit(onSubmit, ()=>{
         console.log('Invalid')})
       }} className="space-y-8">
        <FormField
          control={form.control}
          name="title"
          render={({ field }) => (
            <FormItem>
             <FormLabel>Titre</FormLabel>
             <FormControl>
              <Input {...field} />
             </FormControl>
             <FormDescription>
              Titre de votre êvenement.
             </FormDescription>
             <FormMessage />
            </FormItem>
          )}
        />
        <FormField
          control={form.control}
          name="subTitle"
          render={({ field }) => (
            <FormItem>
             <FormLabel>Sous-titre</FormLabel>
             <FormControl>
              <Input {...field} />
             </FormControl>
             <FormDescription>
              Sous-titre de votre êvenement.
             </FormDescription>
             <FormMessage />
            </FormItem>
          )}
        />
        <FormField
          control={form.control}
          name="base64Banner"
          render={({ field }) => (
            <FormItem>
             <FormLabel>Bannière</FormLabel>
             <FormControl>
              <Input type={"file"} {...field} className={'hover:text-primary'} />
             </FormControl>
             <FormDescription>
              Image de bannière (1Mo max en jpg)
             </FormDescription>
             <FormMessage />
            </FormItem>
          )}
        />
        <FormField
          control={form.control}
          name="desc"
          render={({ field }) => (
            <FormItem>
             <FormLabel>Description</FormLabel>
             <FormControl>
              <Input type={"text"} {...field} />
             </FormControl>
             <FormDescription>
              Description de votre êvenement.
             </FormDescription>
             <FormMessage />
            </FormItem>
          )}
        />
        <FormField
          control={form.control}
          name="date"
          render={({ field }) => (
            <FormItem>
             <FormLabel>Description</FormLabel>
             <FormControl>
              <Input type={"date"} {...field} className={'justify-center'} />
             </FormControl>
             <FormDescription>
              Date de votre êvenement.
             </FormDescription>
             <FormMessage />
            </FormItem>
          )}
        />
        <div className={'flex flex-row gap-1'}>
         <FormField
           control={form.control}
           name="were"
           render={({ field }) => (
             <FormItem className={'w-3/4'}>
              <FormLabel>Lieu</FormLabel>
              <FormControl>
               <Input type={"search"} {...field} />
              </FormControl>
              <FormDescription>
               Lieu de votre êvenement.
              </FormDescription>
              <FormMessage />
             </FormItem>
           )}
         />
         <FormField
           control={form.control}
           name="maxMember"
           render={({ field }) => (
             <FormItem className={'w-3/4'}>
              <FormLabel>Nb de places</FormLabel>
              <FormControl>
               <Input type={"number"} {...field} />
              </FormControl>
              <FormDescription>
               Lieu de votre êvenement.
              </FormDescription>
              <FormMessage />
             </FormItem>
           )}
         />
        </div>
        <Button type="submit">Créer</Button>
       </form>
      </Form>
     </CardContent>
    </Card>
   </>
 )
}
export default NewEventForm;